.. _about:

==============
About openEPDA
==============

openEPDA™ is a collection of open standards to be used in electronic-photonic
design automation. These include definition of data interchange formats to
facilitate Foundry PDK distribution and
easier simulation and measurement data exchange between the parties involved
in the PIC design chain.

Authors
=======
.. include:: ../../AUTHORS